<?php

namespace Drupal\widget_ingestion\Commands;

use Consolidation\OutputFormatters\StructuredData\RowsOfFields;
use Drupal\widget_ingestion\WidgetRemoteRepository;
use Drush\Commands\DrushCommands;

/**
 * Drush command file for widget ingestion.
 */
class WidgetIngestionCommands extends DrushCommands {

  /**
   * The repository of widgets.
   *
   * @var \Drupal\widget_ingestion\WidgetRemoteRepository
   */
  private $widgetsRepository;

  /**
   * WidgetIngestionCommands constructor.
   *
   * @param \Drupal\widget_ingestion\WidgetRemoteRepository $widgets_repository
   *   The repository.
   */
  public function __construct(WidgetRemoteRepository $widgets_repository) {
    parent::__construct();
    $this->widgetsRepository = $widgets_repository;
  }

  /**
   * Ingests all widgets from the associated widget registry.
   *
   * @field-labels
   *   id: ID
   *   name: Name
   *   version: Version
   *   web_segments: Web Segments
   *   translations: Remote Translations
   * @default-fields id,name,version
   *
   * @command widget_ingestion:ingest
   *
   * @return \Consolidation\OutputFormatters\StructuredData\RowsOfFields
   *   The ingested widget types.
   */
  public function ingest() {
    // Ingest the widgets now.
    $items = $this->widgetsRepository->ingestAll();
    $rows = array_map(function (array $item) {
      return [
        'id' => $item['shortcode'],
        'name' => $item['title'],
        'version' => $item['version'],
        'web_segments' => implode(', ', $item['webSegmentPaths']),
        'translations' => implode(', ', $item['availableTranslations']),
      ];
    }, $items);
    return new RowsOfFields($rows);
  }

}
