<?php

namespace Drupal\widget_ingestion\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\widget_ingestion\WidgetRemoteRepository;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form class to ingest the widgets now.
 */
final class ManualIngestionForm extends ConfirmFormBase {

  /**
   * The repository of widgets.
   *
   * @var \Drupal\widget_ingestion\WidgetRemoteRepository
   */
  private $widgetsRepository;

  /**
   * WidgetIngestionCommands constructor.
   *
   * @param \Drupal\widget_ingestion\WidgetRemoteRepository $widgets_repository
   *   The repository.
   */
  public function __construct(WidgetRemoteRepository $widgets_repository) {
    $this->widgetsRepository = $widgets_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get(WidgetRemoteRepository::class));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'widget_ingestion_manual';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Ingest the widgets now.
    $items = $this->widgetsRepository->ingestAll();
    $widgets = implode(', ', array_map(function ($item) {
      return $item['title'];
    }, $items));
    $message = $this->t('Ingested widgets: %widgets', ['%widgets' => $widgets]);
    $this->messenger()->addMessage($message);
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Do you want to ingest the widgets from the registry?');
  }

  /**
   * {@inheritdoc}
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function getCancelUrl() {
    return Url::fromRoute('system.admin_content');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Ingest');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    $endpoint = \Drupal::config('widget_ingestion.settings')->get('endpoint');
    return $this->t(
      'Manual ingestion will update the widget type entities with the latest information from the widget registry.<br /><br />Ingestion URL: %endpoint',
      ['%endpoint' => $endpoint]
    );
  }

}
