<?php

namespace Drupal\widget_ingestion\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Configures widget_ingestion settings for this site.
 *
 * @internal
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'widget_ingestion_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['widget_ingestion.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('widget_ingestion.settings');

    // Global widget_ingestion settings.
    $form['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Endpoint URL'),
      '#size' => 80,
      '#maxlength' => 255,
      '#default_value' => $config->get('endpoint'),
      '#description' => $this->t(
        'A URL containing the JSON feed with the widget definitions to be parsed and imported. @link.',
        [
          '@link' => Link::createFromRoute(
            $this->t('Ingest widget definitions now'),
            'widget_ingestion.manual'
          )->toString(),
        ]
      ),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->config('widget_ingestion.settings');
    $config->set('endpoint', $form_state->getValue('endpoint'));
    $config->save();
  }

}
